@@ -3,7 +3,8 @@ leafletSimpleGraticuleDependencies <- function() {
     htmltools::htmlDependency(
       "leaflet-simplegraticule",
       "0.1.0",
-      system.file("htmlwidgets/plugins/Leaflet.SimpleGraticule", package = "leaflet"),
+      "htmlwidgets/plugins/Leaflet.SimpleGraticule",
+      package = "leaflet",
       script = c("L.SimpleGraticule.js", "SimpleGraticule-binding.js"),
       stylesheet = "L.SimpleGraticule.css"
     )
